"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NitroxLabCore = exports.InputType = exports.Units = void 0;
var Units;
(function (Units) {
    Units["METRIC"] = "metric";
    Units["IMPERIAL"] = "imperial";
})(Units = exports.Units || (exports.Units = {}));
var InputType;
(function (InputType) {
    InputType[InputType["DEPTH"] = 0] = "DEPTH";
    InputType[InputType["PPO2MAX"] = 1] = "PPO2MAX";
    InputType[InputType["FO2"] = 2] = "FO2";
})(InputType = exports.InputType || (exports.InputType = {}));
class NitroxLabCore {
    constructor(options) {
        const { units, defaultPpO2Max } = options || {};
        this.units = units ? units : Units.METRIC;
        this.defaultPpO2Max = defaultPpO2Max ? defaultPpO2Max : 1.4;
    }
    convDepth(depth, target) {
        const factor = 3.281;
        if (target === Units.IMPERIAL) {
            return depth * factor;
        }
        else {
            return depth / factor;
        }
    }
    validateInput(value, type) {
        switch (type) {
            case InputType.DEPTH:
                if (!(typeof value === 'number' && value > 0)) {
                    throw new Error('Incorrect depth');
                }
                break;
            case InputType.FO2:
                if (!(typeof value === 'number' && value > 0)) {
                    throw new Error('Incorrect fO2');
                }
                break;
            case InputType.PPO2MAX:
                if (!(typeof value === 'number' && value > 0)) {
                    throw new Error('Incorrect ppO2Max');
                }
                break;
            default:
                throw new Error('Unknown input validation type');
        }
    }
    numFixed(num, digits, mode) {
        const pwr = Math.pow(10, digits);
        return Math[mode](num * pwr) / pwr;
    }
    calcMOD(fO2, ppO2Max) {
        this.validateInput(fO2, InputType.FO2);
        this.validateInput(ppO2Max, InputType.PPO2MAX);
        let mod = ((ppO2Max * 10) / fO2) - 10;
        if (this.units === Units.IMPERIAL) {
            mod = this.convDepth(mod, Units.IMPERIAL);
        }
        return this.numFixed(mod, 2, 'floor');
    }
    calcBestMix(depth, ppO2Max) {
        this.validateInput(depth, InputType.DEPTH);
        this.validateInput(ppO2Max, InputType.PPO2MAX);
        let d = depth;
        if (this.units === Units.IMPERIAL) {
            d = this.convDepth(d, Units.METRIC);
        }
        let bestMix = ppO2Max / ((d / 10) + 1);
        if (bestMix > 1) {
            bestMix = 1;
        }
        return this.numFixed(bestMix, 2, 'floor');
    }
    calcTopOff(options) {
        const { currentMix, topOffMix, targetPressure } = options;
        const currentO2P = currentMix.fO2 * currentMix.p;
        const topOffO2P = topOffMix.fO2 * (targetPressure - currentMix.p);
        const endO2P = currentO2P + topOffO2P;
        const endFO2 = endO2P / targetPressure;
        return this.numFixed(endFO2, 3, 'ceil');
    }
}
exports.NitroxLabCore = NitroxLabCore;
