"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const index_1 = require("../index");
describe('Calculations', () => {
    describe('Maximum operating depth', () => {
        it('Should calculate MOD metric', () => {
            const nx = new index_1.NitroxLabCore();
            // [pO2, ppO2Max, MOD]
            const modCasesMetric = [
                [0.32, 1.4, 33.75],
                [0.36, 1.4, 28.88]
            ];
            modCasesMetric.forEach(modCase => {
                const [caseEan, casePpO2Max, caseMOD] = modCase;
                const result = nx.calcMOD(caseEan, casePpO2Max);
                chai_1.assert.strictEqual(result, caseMOD);
            });
        });
        it('Should calculate MOD imperial', () => {
            const nx = new index_1.NitroxLabCore({ units: index_1.Units.IMPERIAL });
            const modCasesImperial = [
                [0.32, 1.4, 110.73],
                [0.36, 1.4, 94.78]
            ];
            modCasesImperial.forEach(modCase => {
                const [caseEan, casePpO2Max, caseMOD] = modCase;
                const result = nx.calcMOD(caseEan, casePpO2Max);
                chai_1.assert.strictEqual(result, caseMOD);
            });
        });
        it('Should throw on incorrect fO2 range', () => {
            const nx = new index_1.NitroxLabCore();
            const eanValues = [0, -32, -321, -0];
            eanValues.forEach(fO2 => {
                chai_1.assert.throws(() => nx.calcMOD(fO2, 1.4), 'Incorrect fO2');
            });
        });
        it('Should throw on incorrect ppO2Max range', () => {
            const nx = new index_1.NitroxLabCore();
            const ppO2MaxValues = [0, -3, -0, -0.12, null, undefined];
            ppO2MaxValues.forEach(ppO2Max => {
                chai_1.assert.throws(() => nx.calcMOD(32, ppO2Max), 'Incorrect ppO2Max');
            });
        });
    });
    describe('Best mix', () => {
        it('Should calculate best mix metric', () => {
            const nx = new index_1.NitroxLabCore();
            const bestMixCasesMetric = [
                [33, 1.4, 0.32],
                [3, 1.4, 1]
            ];
            bestMixCasesMetric.forEach(bestMixCase => {
                const [caseDepth, casePPO2Max, caseBestMix] = bestMixCase;
                const bestMix = nx.calcBestMix(caseDepth, casePPO2Max);
                chai_1.assert.strictEqual(bestMix, caseBestMix);
            });
        });
        it('Should calculate best mix imperial', () => {
            const nx = new index_1.NitroxLabCore({ units: index_1.Units.IMPERIAL });
            const bestMixCasesImperial = [
                [110, 1.4, 0.32]
            ];
            bestMixCasesImperial.forEach(bestMixCase => {
                const [caseDepth, casePPO2Max, caseBestMix] = bestMixCase;
                const bestMix = nx.calcBestMix(caseDepth, casePPO2Max);
                chai_1.assert.strictEqual(bestMix, caseBestMix);
            });
        });
        it('Should throw on incorrect depth range', () => {
            const nx = new index_1.NitroxLabCore();
            const incorrectDepths = [-42, -1, 0];
            incorrectDepths.forEach((depth) => {
                chai_1.assert.throws(() => nx.calcBestMix(depth, 1.4), 'Incorrect depth');
            });
        });
    });
    describe('Gas mixing', () => {
        describe('Top off', () => {
            it('Should calculate top off result', () => {
                const nx = new index_1.NitroxLabCore();
                const topOffCases = [
                    {
                        currentMix: { fO2: 0.32, p: 100 },
                        topOffMix: { fO2: 0.21 },
                        targetPressure: 200,
                        resultFO2: 0.265
                    },
                    {
                        currentMix: { fO2: 0.21, p: 50 },
                        topOffMix: { fO2: 0.32 },
                        targetPressure: 210,
                        resultFO2: 0.294
                    }
                ];
                topOffCases.forEach(topOffCase => {
                    const { currentMix, topOffMix, targetPressure, resultFO2 } = topOffCase;
                    const result = nx.calcTopOff({ currentMix, topOffMix, targetPressure });
                    chai_1.assert.strictEqual(result, resultFO2);
                });
            });
        });
    });
});
